function [] = point_display(sys,U)

H=sys.H;
DHp1 = 2*H+1;

if strcmp(sys.type,'HBM')
    
    % Computation of the periodic solution over 1 period : time is a
    % dimensionless time vector.
    time = linspace(0,1,1000);
    Ut = calcperiodHBM(sys,U,[1 2],time);
    
else
    % Time reconstruction in the matrix Ut(nt,nz) --- Quasi-Periodic case
    [Ztot,omega1,omega2,lambda]=sys.get_Ztot(U);
    Tmax=2*pi/omega1 + 2*pi/omega2;
    nb = 200;
    time=linspace(0,nb*Tmax,nb*400);
    nt=length(time);
    
    Zcompl = sys.real_to_compl(Ztot);
    
    VectExp=zeros(nt,H*(DHp1+1));
    for k=1:H
        VectExp(:,k) = exp(1i*omega2*k*time);
    end
    for l=1:H
        for k=-H:1:H
            VectExp(:,l*DHp1+k) = exp(1i*(l*omega1+k*omega2)*time);
        end
    end
    MAT = [ones(nt,1) , VectExp];
    Ut = real(MAT*Zcompl);
    
end

figure(11);
plot(time,Ut(:,1),'b',time,Ut(:,2),'r')
title(['Time evolution of u and v with ' num2str(H) ' harmonics'],'Fontsize',16)
xlabel('time (s)');legend(['u'],['v'],'Location','SouthEast');grid on;

figure(12)
plot(Ut(:,1),Ut(:,2))
xlabel('u');ylabel('v');

end
